==> knative-model-4.5.2-sources.jar: io/fabric8/knative/eventing/v1alpha1/ClusterChannelProvisionerListFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterChannelProvisionerListFluent<A extends ClusterChannelProvisionerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ClusterChannelProvisioner item);
    public A setToItems(int index,ClusterChannelProvisioner item);
    public A addToItems(ClusterChannelProvisioner... items);
    public A addAllToItems(Collection<ClusterChannelProvisioner> items);
    public A removeFromItems(ClusterChannelProvisioner... items);
    public A removeAllFromItems(Collection<ClusterChannelProvisioner> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ClusterChannelProvisioner> getItems();
    public List<ClusterChannelProvisioner> buildItems();
    public ClusterChannelProvisioner buildItem(int index);
    public ClusterChannelProvisioner buildFirstItem();
    public ClusterChannelProvisioner buildLastItem();
    public ClusterChannelProvisioner buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public A withItems(List<ClusterChannelProvisioner> items);
    public A withItems(ClusterChannelProvisioner... items);
    public Boolean hasItems();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> addNewItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> addNewItemLike(ClusterChannelProvisioner item);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> setNewItemLike(int index,ClusterChannelProvisioner item);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editItem(int index);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editFirstItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editLastItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterChannelProvisionerFluent<ClusterChannelProvisionerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> knative-model-4.6.4-sources.jar: io/fabric8/knative/eventing/v1alpha1/ClusterChannelProvisionerListFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ClusterChannelProvisionerListFluent<A extends ClusterChannelProvisionerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ClusterChannelProvisioner item);
    public A setToItems(int index,ClusterChannelProvisioner item);
    public A addToItems(ClusterChannelProvisioner... items);
    public A addAllToItems(Collection<ClusterChannelProvisioner> items);
    public A removeFromItems(ClusterChannelProvisioner... items);
    public A removeAllFromItems(Collection<ClusterChannelProvisioner> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ClusterChannelProvisioner> getItems();
    public List<ClusterChannelProvisioner> buildItems();
    public ClusterChannelProvisioner buildItem(int index);
    public ClusterChannelProvisioner buildFirstItem();
    public ClusterChannelProvisioner buildLastItem();
    public ClusterChannelProvisioner buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public A withItems(List<ClusterChannelProvisioner> items);
    public A withItems(ClusterChannelProvisioner... items);
    public Boolean hasItems();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> addNewItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> addNewItemLike(ClusterChannelProvisioner item);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> setNewItemLike(int index,ClusterChannelProvisioner item);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editItem(int index);
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editFirstItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editLastItem();
    public ClusterChannelProvisionerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ClusterChannelProvisionerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterChannelProvisionerFluent<ClusterChannelProvisionerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
